@@ -1,8 +1,7 @@
-// blumshub.h - written and placed in the public domain by Wei Dai
+// blumshub.h - originally written and placed in the public domain by Wei Dai
 
-//! \file
-//! \headerfile blumshub.h
-//! \brief Classes for Blum Blum Shub generator
+/// \file blumshub.h
+/// \brief Classes for Blum Blum Shub generator
 
 #ifndef CRYPTOPP_BLUMSHUB_H
 #define CRYPTOPP_BLUMSHUB_H
@@ -13,11 +12,13 @@
 
 NAMESPACE_BEGIN(CryptoPP)
 
-//! BlumBlumShub without factorization of the modulus
+/// BlumBlumShub without factorization of the modulus
 class PublicBlumBlumShub : public RandomNumberGenerator,
 						   public StreamTransformation
 {
 public:
+	virtual ~PublicBlumBlumShub() {}
+
 	PublicBlumBlumShub(const Integer &n, const Integer &seed);
 
 	unsigned int GenerateBit();
@@ -27,10 +28,6 @@ public:
 
 	bool IsSelfInverting() const {return true;}
 	bool IsForwardTransformation() const {return true;}
-	
-#ifndef CRYPTOPP_MAINTAIN_BACKWARDS_COMPATIBILITY_562
-	virtual ~PublicBlumBlumShub() {}
-#endif
 
 protected:
 	ModularArithmetic modn;
@@ -38,21 +35,19 @@ protected:
 	word maxBits, bitsLeft;
 };
 
-//! BlumBlumShub with factorization of the modulus
+/// BlumBlumShub with factorization of the modulus
 class BlumBlumShub : public PublicBlumBlumShub
 {
 public:
+	virtual ~BlumBlumShub() {}
+
 	// Make sure p and q are both primes congruent to 3 mod 4 and at least 512 bits long,
 	// seed is the secret key and should be about as big as p*q
 	BlumBlumShub(const Integer &p, const Integer &q, const Integer &seed);
-	
+
 	bool IsRandomAccess() const {return true;}
 	void Seek(lword index);
 
-#ifndef CRYPTOPP_MAINTAIN_BACKWARDS_COMPATIBILITY_562
-	virtual ~BlumBlumShub() {}
-#endif
-
 protected:
 	const Integer p, q;
 	const Integer x0;
